aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorBonfaceKilz2021-06-07 10:21:33 +0300
committerBonfaceKilz2021-06-07 19:58:44 +0300
commit25875d1eb08360fa2ef4ecf1753913a0513612bc (patch)
treec223783c1dd69e5ea4b83d0408ca25d256540589
parent4ea2b135b91baf259f813c4056963ead88ed17d3 (diff)
downloadgenenetwork3-25875d1eb08360fa2ef4ecf1753913a0513612bc.tar.gz
tests: test_db: Rename TestPhenotype
-rw-r--r--tests/unit/db/test_db.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/tests/unit/db/test_db.py b/tests/unit/db/test_db.py
index a3b1d71..2e38d4c 100644
--- a/tests/unit/db/test_db.py
+++ b/tests/unit/db/test_db.py
@@ -8,8 +8,8 @@ from gn3.db import diff_from_dict
from gn3.db.phenotypes import Phenotype
-class TestPhenotypes(TestCase):
- """Test cases for fetching chromosomes"""
+class TestCrudMethods(TestCase):
+ """Test cases for CRUD methods"""
def test_update_phenotype_with_no_data(self):
"""Test that a phenotype is updated correctly if an empty Phenotype dataclass